@@ -8,6 +8,7 @@ to add cross origin support to your flask app!
 :license:   MIT/X11, see LICENSE for more details.
 """
 from flask import Flask, jsonify
+import logging
 try:
     # The typical way to import flask-cors
     from flask.ext.cors import cross_origin
@@ -20,8 +21,8 @@ except ImportError:
     from flask.ext.cors import cross_origin
 
 
-app = Flask(__name__)
-
+app = Flask('FlaskCorsViewBasedExample')
+logging.basicConfig(level=logging.INFO)
 
 @app.route("/", methods=['GET'])
 @cross_origin()
@@ -31,26 +32,27 @@ def helloWorld():
         configuration of view-based decoration. The expected result is as
         follows:
 
-        $ http get http://127.0.0.1:5000/
-        HTTP/1.0 200 OK
-        Access-Control-Allow-Origin: *
-        Content-Length: 184
+        $ curl --include -X GET http://127.0.0.1:5000/ \
+            --header Origin:www.examplesite.com
+
+        >> HTTP/1.0 200 OK
         Content-Type: text/html; charset=utf-8
-        Date: Sat, 09 Aug 2014 00:35:39 GMT
-        Server: Werkzeug/0.9.4 Python/2.7.8
+        Content-Length: 184
+        Access-Control-Allow-Origin: *
+        Server: Werkzeug/0.9.6 Python/2.7.9
+        Date: Sat, 31 Jan 2015 22:29:56 GMT
 
         <h1>Hello CORS!</h1> Read about my spec at the
-        <a href="http://www.w3.org/TR/cors/">W3</a> Or, checkout my
-        documentation on <a href="https://github.com/wcdolphin/flask-cors">
-        Github</a>
+        <a href="http://www.w3.org/TR/cors/">W3</a> Or, checkout my documentation
+        on <a href="https://github.com/corydolphin/flask-cors">Github</a>
 
     '''
     return '''<h1>Hello CORS!</h1> Read about my spec at the
 <a href="http://www.w3.org/TR/cors/">W3</a> Or, checkout my documentation
-on <a href="https://github.com/wcdolphin/flask-cors">Github</a>'''
+on <a href="https://github.com/corydolphin/flask-cors">Github</a>'''
 
 
-@app.route("/user/create", methods=['GET', 'POST'])
+@app.route("/api/v1/user/create", methods=['GET', 'POST'])
 @cross_origin(allow_headers=['Content-Type'])
 def cross_origin_json_post():
     '''
@@ -58,17 +60,38 @@ def cross_origin_json_post():
         to send the Content-Type header, allowing cross domain AJAX POST
         requests.
 
-        $ http post http://127.0.0.1:5000/user/create
-        HTTP/1.0 200 OK
-        Access-Control-Allow-Headers: Content-Type
+ Browsers will first make a preflight request to verify that the resource
+        allows cross-origin POSTs with a JSON Content-Type, which can be simulated
+        as:
+        $ curl --include -X OPTIONS http://127.0.0.1:5000/api/v1/users/create \
+            --header Access-Control-Request-Method:POST \
+            --header Access-Control-Request-Headers:Content-Type \
+            --header Origin:www.examplesite.com
+        >> HTTP/1.0 200 OK
+        Content-Type: text/html; charset=utf-8
+        Allow: POST, OPTIONS
         Access-Control-Allow-Origin: *
-        Content-Length: 21
+        Access-Control-Allow-Headers: Content-Type
+        Access-Control-Allow-Methods: DELETE, GET, HEAD, OPTIONS, PATCH, POST, PUT
+        Content-Length: 0
+        Server: Werkzeug/0.9.6 Python/2.7.9
+        Date: Sat, 31 Jan 2015 22:25:22 GMT
+
+
+        $ curl --include -X POST http://127.0.0.1:5000/api/v1/users/create \
+            --header Content-Type:application/json \
+            --header Origin:www.examplesite.com
+
+
+        >> HTTP/1.0 200 OK
         Content-Type: application/json
-        Date: Sat, 09 Aug 2014 00:38:47 GMT
-        Server: Werkzeug/0.9.4 Python/2.7.8
+        Content-Length: 21
+        Access-Control-Allow-Origin: *
+        Server: Werkzeug/0.9.6 Python/2.7.9
+        Date: Sat, 31 Jan 2015 22:25:04 GMT
 
         {
-            "success": true
+          "success": true
         }
 
     '''
